@@ -58,6 +58,7 @@ class ZebrunnerAPI(metaclass=Singleton):
         authenticated (bool): True when a valid access token is given.
 
     """
+
     authenticated = False
 
     def __init__(self, service_url: str = None, access_token: str = None):
@@ -66,12 +67,11 @@ class ZebrunnerAPI(metaclass=Singleton):
             service_url (str): Url to access Zebrunner API. None by default.
             access_token (str): Access token to access Zebrunner API. None by default.
         """
-        if service_url and access_token:
-            self.service_url = service_url.rstrip("/")
-            self.access_token = access_token
-            self._client = Client()
-            self._auth_token = None
-            self.authenticated = False
+        self.service_url = service_url.rstrip("/") if service_url else ""
+        self.access_token = access_token
+        self._client = Client()
+        self._auth_token = None
+        self.authenticated = False
 
     def _sign_request(self, request: Request) -> Request:
         """
@@ -344,8 +344,7 @@ class ZebrunnerAPI(metaclass=Singleton):
         self._client.put(url, json=body.dict(exclude_none=True, by_alias=True))
 
     def get_rerun_tests(self, run_context: str) -> RerunDataModel:
-        """
-        """
+        """"""
         url = self.service_url + "/api/reporting/v1/run-context-exchanges"
         run_context_dict = json.loads(run_context)
         response = self._client.post(url, json=run_context_dict)
