@@ -23,10 +23,11 @@ class SeleniumSession:
             self._active_sessions[session_id]["zebrunner_session_id"] = zebrunner_session_id
 
     def finish_session(self, session_id: str) -> None:
-        self.reporting_service.finish_test_session(
-            self._active_sessions[session_id]["zebrunner_session_id"],
-            self._active_sessions[session_id]["related_tests"],
-        )
+        if zebrunner_context.test_run_is_active:
+            self.reporting_service.finish_test_session(
+                self._active_sessions[session_id]["zebrunner_session_id"],
+                self._active_sessions[session_id]["related_tests"],
+            )
         del self._active_sessions[session_id]
 
     def finish_all_sessions(self) -> None:
@@ -46,7 +47,7 @@ def inject_driver(session_manager: SeleniumSession) -> None:
         from selenium.webdriver.remote.webdriver import WebDriver
 
         base_init = WebDriver.__init__
-        base_close = WebDriver.close
+        base_quit = WebDriver.quit
 
         def init(session, *args, **kwargs) -> None:  # type: ignore
             base_init(session, *args, **kwargs)
@@ -58,7 +59,7 @@ def inject_driver(session_manager: SeleniumSession) -> None:
 
         def quit(session) -> None:  # type: ignore
             session_manager.finish_session(session.session_id)
-            base_close(session)
+            base_quit(session)
 
         WebDriver.__init__ = init
         WebDriver.quit = quit
