@@ -18,6 +18,7 @@ class ZebrunnerHandler(StreamHandler):
     Attributes:
         logs (List[LorRecordModel]): List of logs to be handled.
     """
+
     logs: List[LogRecordModel] = []
 
     def __init__(self) -> None:
@@ -52,8 +53,8 @@ class ZebrunnerHandler(StreamHandler):
         for reporting if test_run_id is active.
 
         """
-        try:    
-            if zebrunner_context.test_run_id and zebrunner_context.settings.send_logs:
+        try:
+            if zebrunner_context.test_run_is_active and zebrunner_context.settings.send_logs:
                 self.api.send_logs(zebrunner_context.test_run_id, self.logs)
         except httpx.HTTPError as e:
             logging.error("Failed to send logs to zebrunner", exc_info=e)
